@@ -1,5 +1,6 @@
 use hex::*;
 use base64::*;
+use bs58::*;
 use blake2_rfc::blake2b::*;
 
 pub struct EncodingAPI;
@@ -17,6 +18,12 @@ impl EncodingAPI {
     pub fn encode_into_base64<T: AsRef<[u8]>>(s: T) -> String {
         return base64::encode(s.as_ref())
     }
+    pub fn encode_into_base58<T: AsRef<[u8]>>(s: T) -> String {
+        return bs58::encode(s.as_ref()).into_string()
+    }
+    pub fn decode_from_base58<T: AsRef<str>>(s: T) -> Vec<u8> {
+        return bs58::decode(s.as_ref()).into_vec().expect("Failed To Decode From Base58")
+    }
 }
 
 pub struct HashEncoderAPI;
