@@ -1,4 +1,6 @@
 extern crate serde;
+#[macro_use]
+extern crate serde_big_array;
 
 /// Global Constants
 pub mod constants;
@@ -15,9 +17,12 @@ pub mod os_random;
 
 pub mod seed;
 
+/// Falcon1024, a Lattice-Based crytography 
 pub mod falcon;
+/// BLS Signatures that can be aggregated
 pub mod bls;
 pub mod schnorr;
+pub mod ed25519;
 
 #[cfg(test)]
 mod tests {
