@@ -8,6 +8,7 @@ use rand_chacha::ChaCha20Rng;
 use crate::seed::*;
 use crate::os_random::*;
 use bs58::*;
+use base32::Alphabet as Base32Alphabet;
 
 use serde::{Serialize,Deserialize};
 
@@ -110,6 +111,9 @@ impl SchnorrSignature {
 }
 
 impl SchnorrKeypair {
+    pub fn return_pk_as_base32(&self) -> String {
+        return base32::encode(Base32Alphabet::Crockford, &self.pk)
+    }
     pub fn return_pk_as_hex(&self) -> String {
         return hex::encode_upper(self.pk)
     }
@@ -206,4 +210,13 @@ fn schnorr_generation_from_seed(){
     let is_valid2 = signature2.verify();
 
     println!("Is Valid: {}",is_valid2);
+}
+
+#[test]
+fn schnorr_base32(){
+    let phrase = BIP39API::generate(Language::English);
+    let seed = phrase.derive_seed("Password1234", Language::English);
+
+    let keypair = SchnorrKeypair::new(&seed.as_bytes());
+    println!("{}",keypair.return_pk_as_base32());
 }
\ No newline at end of file
